powered by
Basic descriptive and market data for those securities in the DJIA as of the end of January, 2005.
data(dow.jan.2005)
A data frame with 500 observations on the following 15 variables.
symbol
a character vector
name
cap.bil
a numeric vector
price
sector
a factor with levels Communications Conglomerates Cyclicals Energy Financials Industrials Materials Staples Technology Utilities
Communications
Conglomerates
Cyclicals
Energy
Financials
Industrials
Materials
Staples
Technology
Utilities
month.ret
# NOT RUN { data(dow.jan.2005) # }
Run the code above in your browser using DataLab