global.2004.history: portfolioHistory object formed from the global.2004 dataset
Description
Contains an object of class portfolioHistory that contains
exposure, performance, and contribution data for twelve portfolios
formed from the twelve time periods in the global.2004 dataset.Usage
data(global.2004.history)
format
Formal class 'portfolioHistory' [package "portfolio"] with 7 slots.Details
The portfolios added to this portfolioHistory object were long
short, of type sigmoid, and were
formed using the top and bottom quintiles of the cap.bil
variable.