Learn R Programming

portfolio (version 0.2-2)

portfolio-class: Class "portfolio"

Description

Class "portfolio" extends class "portfolioBasic" to include price and share information. Price information must be included in the supplementary "data" slot.

Arguments

Objects from the Class

Objects can be created by calls of the form new("portfolio", ...).

Extends

Class "portfolioBasic", directly.