Learn R Programming

portfolio (version 0.3-3)

tradelist-class: Class "tradelist"

Description

Note: This class is a rough first pass and will change drastically in future releases. An object of the class "tradelist" containing a data frame of trades and a data frame of supplementary information.

Arguments

Objects from the Class

Objects can be created by calls of the form new("tradelist", orig, target, ...).