Learn R Programming

portfolio (version 0.4-3)

trades-class: Class "trades"

Description

An object of the class "trades" contains a data frame with columns "id", "side", and "shares" describing a simple list of trades to be performed.

Arguments

Objects from the Class

Objects can be created by calls of the form new("trades", ...).

Methods

No methods defined with class "trades" in the signature.

See Also

tradelist-class

Examples

Run this code
df <- data.frame(id = c(1,2,3), side = c("B","X","C"), shares = c(10,20,30))

t <- new("trades", trades = df)

Run the code above in your browser using DataLab