matchedPortfolio-class: Class "matchedPortfolio"
Description
An object of the class "matchedPortfolio" that contains an
object of class "portfolioBasic" and a matrix of weights for
portfolios that have been matched to the "portfolioBasic" according to
variables specified in a formula.Objects from the Class
Objects can be created by calls of the form new("matchedPortfolio", ...).Details
The matches matrix contains as many rows as there are stocks in
the data slot of original and as many columns as there
are matched portfolios. The row labels of the matrix are the values of
original@data[["id.var"]] and each column is a matched
portfolio. The cell values are the weights of the stock in the
portfolio.