powered by
An object of the class "trades" contains a data frame with columns "id", "side", and "shares" describing a simple list of trades to be performed.
Objects can be created by calls of the form new("trades", ...).
new("trades", ...)
trades
Object of class "data.frame" with columns "id", "side", and "shares".
"data.frame"
No methods defined with class "trades" in the signature.
tradelist-class
# NOT RUN { df <- data.frame(id = c(1,2,3), side = c("B","X","C"), shares = c(10,20,30)) t <- new("trades", trades = df) # }
Run the code above in your browser using DataLab